#region Copyright  2006-2008 Eliwell Controls srl
//
// All rights are reserved.
// Reproduction or transmission in whole or in part, in any form
// or by any means, electronic, mechanical or otherwise, is prohibited
// without the prior written consent of the copyright owner.
//
// Filename: NetworksFieldBus.aspx.cs
//
#endregion

using System;
using System.Collections.Generic;
using System.Web.UI;
using Invensys.BusinessObjects;
using Invensys.Enums;
using Invensys.Presentation.Common;

using Invensys.Presentation.Web.UC;
using Invensys.Dictionary;

namespace Invensys.Presentation.Web.Settings
{
    public partial class NetworksFieldBus : WebPage
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            ToolBar1.ButtonClick += new ButtonClickEventHandler(PageToolbar1_ButtonClick);
            if (SupervisorStatus.DataAcquisitionStatus == DataAcquisitionStatus.Running)
            {
                // display error message
                GeneralMessage1.Text =
                    DictionaryFacade.GetDictionaryItem((String)Session[SessionConstants.WEB_USER_CULTURE_CODE], 1, DictionaryConstants.IT_IS_NECESSARY_TO_STOP_DATA_ACQUISITION_1);
                // hide commands and filter
                ToolBar1.Visible = false;  // this is redundant
                Control toolbarPanel = Master.FindControl("WkaToolbarArea");
                if (toolbarPanel != null)
                    toolbarPanel.Visible = false;
                Control filterPanel = Master.FindControl("WkaFilterArea");
                if (filterPanel != null)
                    filterPanel.Visible = false;
            }
            else
            {
                GeneralMessage1.Visible = false;
                ToolBar1.Visible = true;
                LoadNetworksGrid();
            }

            SetFilter();
        }
        
        private void LoadNetworksGrid()
        {
            // load ONLINE networks/devices/resources
            //IList<FullNetwork> networks = NetworksGridManager.LoadCurrentNetworks(true);
            //NetworksGrid1.Networks = networks;
            NetworksGridSiteDTO siteDTO = NetworksGridManager.Instance.GetSiteDTO(true, (String)Session[SessionConstants.WEB_USER_CULTURE_CODE], false);
            NetworksGrid1.Networks = siteDTO.Networks;

            NetworksGrid1.ShowLevel = VisibleLevel.OneTwo;

            NetworksGrid1.Level1.ColumnsDictionary[ColumnType.Icon.ToString()].Visible = true;
            NetworksGrid1.Level1.ColumnsDictionary[ColumnType.Level1Interface.ToString()].Visible = true;
            NetworksGrid1.Level1.ColumnsDictionary[ColumnType.Level1License.ToString()].Visible = true;
            NetworksGrid1.Level1.ColumnsDictionary[ColumnType.Level1Port.ToString()].Visible = true;
            NetworksGrid1.Level1.ColumnsDictionary[ColumnType.Level1DevicesCount.ToString()].Visible = true;

            NetworksGrid1.Level2.ColumnsDictionary[ColumnType.Icon.ToString()].Visible = true;
            NetworksGrid1.Level2.ColumnsDictionary[ColumnType.Level2Address.ToString()].Visible = true;
            NetworksGrid1.Level2.ColumnsDictionary[ColumnType.Level2CalculatedName.ToString()].Visible = true;
            NetworksGrid1.Level2.ColumnsDictionary[ColumnType.Level2ProfileSelect.ToString()].Visible = true;
        }

        void PageToolbar1_ButtonClick(object sender, ToolbarEventArgs ea)
        {
            switch (ea.ToolbarButtonType)
            {
                case ToolbarButtonType.GridSave:
                    // save selected FieldBus

                    // read selected FieldBus from posted info
                    IList<NetworksGridNetworkDTO> networksToCompareWithPostedInfo = NetworksGrid1.Networks;
                    NetworksGridPostedSiteInfo postedInfo = NetworksGrid.LoadPostedItems(Request, networksToCompareWithPostedInfo, 2);

                    NetworksGridManager.Instance.SaveSite(postedInfo, LogicalDataChange.FieldBus);

                    // redirect to message page
                    Response.Redirect(WebFormsConstants.SETTINGS_NETWORKS_SAVED_MESSAGE_ASPX);
                    break;
                case ToolbarButtonType.GridCancel:
                    Response.Redirect(WebFormsConstants.SETTINGS_NETWORKS_FIELDBUS_ASPX);
                    break;
            }
        }

        protected void SetFilter()
        {
            NetworkFilter1.DevicesSection.Visible = true;
            NetworkFilter1.DevicesSection.ColumnDescriptionPosition1Based = 4;
            NetworkFilter1.MaintenanceSection.Visible = false;
            NetworkFilter1.VisualHelpersSection.Visible = true;
        }

        protected override void SetLabels()
        {
            
        }

        protected override void SetImages()
        {
            
        }

        protected override void SetTitle()
        {
            PageTitle1.AddLevel(DictionaryFacade.GetDictionaryItem((String)Session[SessionConstants.WEB_USER_CULTURE_CODE], 1, DictionaryConstants.SETTINGS_1));
            PageTitle1.AddLevel(DictionaryFacade.GetDictionaryItem((String)Session[SessionConstants.WEB_USER_CULTURE_CODE], 1, DictionaryConstants.NETWORKS_1));
            PageTitle1.AddLevel(DictionaryFacade.GetDictionaryItem((String)Session[SessionConstants.WEB_USER_CULTURE_CODE], 1, DictionaryConstants.FIELDBUS_1));
        }
    }
}
