-------------------------------------------------------
-- DB Version        _      __     __     __
--                  / |    /_ \   /  \   /  \
--                   ||    _|.|   |()|   |()|
--                  |__| o \__/ o \__/ o \__/
-------------------------------------------------------
CREATE TABLE [DbProperties] ([Key] ntext NOT NULL,	[Value] ntext);
INSERT INTO [DbProperties]([Key], [Value]) VALUES ('Version', '1.3.0.0');

--  Create Tables
CREATE TABLE [Profiles] ( 
	[ID] int identity(1,1)  NOT NULL,
	[Name] ntext NOT NULL,
	[ResourceCoordinates] ntext NOT NULL,
	[IsAbsolute] bit NOT NULL,
	[FromDate] datetime,
	[ToDate] datetime,
	[IntervalType] int
)
;

CREATE TABLE [PermissionSettings] ( 
	[ID] int identity(1,1)  NOT NULL,
	[IDUserGroups] int NOT NULL,
	[IDPermissions] int NOT NULL,
	[Level] int NOT NULL
)
;

CREATE TABLE [Users] ( 
	[ID] int identity(1,1)  NOT NULL,
	[IDUserGroups] int NOT NULL,
	[Name] nvarchar(255) NOT NULL,
	[Description] ntext,
	[PasswordEncryption] nvarchar(50),
	[StartPage] int,
	[IsEnabled] bit NOT NULL,
	[IsDefaultAdministrator] bit NOT NULL
)
;

CREATE TABLE [UserGroups] ( 
	[ID] int identity(1,1)  NOT NULL,
	[Name] nvarchar(255) NOT NULL,
	[Description] ntext,
	[IsEnabled] bit NOT NULL,
	[IsDefaultAdministrator] bit NOT NULL
)
;

CREATE TABLE [Timeframes] ( 
	[ID] int identity(1,1)  NOT NULL,
	[Type] smallint NOT NULL,
	[Name] ntext NOT NULL,
	[FromTime] datetime NOT NULL,
	[ToTime] datetime NOT NULL,
	[FromDay] smallint,
	[ToDay] smallint,
	[IsContinuous] bit,
	[IsEnabled] bit NOT NULL
)
;

CREATE TABLE [BusinessActions] ( 
	[ID] int identity(1,1)  NOT NULL,
	[Name] ntext NOT NULL,
	[Description] ntext,
	[Settings] ntext NOT NULL,
	[TypeGuid] uniqueidentifier NOT NULL,
	[IsEnabled] bit NOT NULL,
	[IsCondemned] bit NOT NULL
)
;

CREATE TABLE [AlarmCategoriesTimeframes] ( 
	[IDAlarmCategory] int NOT NULL,
	[IDTimeframe] int NOT NULL
)
;

CREATE TABLE [AlarmCategoriesBusinessActions] ( 
	[IDAlarmCategory] int NOT NULL,
	[IDBusinessAction] int NOT NULL
)
;

CREATE TABLE [AlarmCategories] ( 
	[ID] int identity(1,1)  NOT NULL,
	[Name] ntext NOT NULL,
	[AppliesToAllDevices] bit NOT NULL,
	[DeviceFilter] ntext,
	[AppliesToAllAlarms] bit NOT NULL,
	[AlarmFilter] ntext,
	[Escalate] bit NOT NULL,
	[IsEnabled] bit NOT NULL
)
;

CREATE TABLE [Sites] ( 
	[ID] int identity(1,1)  NOT NULL,
	[ValidStartTime] datetime NOT NULL,
	[ValidEndTime] datetime,
	[HasData] bit NOT NULL,
	[HistoricalSerializerVersion] smallint
)
;

CREATE TABLE [Resources] ( 
	[ID] int identity(1,1)  NOT NULL,
	[IDSites] int NOT NULL,
	[Origin] smallint DEFAULT 0 NOT NULL,
	[Coordinates] ntext NOT NULL,
	[NameCode] ntext NOT NULL,
	[ResourceType] smallint NOT NULL,
	[DataValueType] smallint NOT NULL,
	[ShortName] ntext,
	[MeasurementUnitCode] nchar(8),
	[IsOnline] bit NOT NULL,
	[Labels] ntext NOT NULL,
	[HasToBeSaved] bit NOT NULL,
	[HistoricalValueTypeLength] int,
	[HistoricalDecimalPosition] int,
	[HistoricalIsSigned] bit,
	[UserDefinedLongName] ntext,
	[UserDefinedShortName] ntext,
	[UserDefinedAlarmDelay] int,
	[UserDefinedIsPreferred] bit
)
;

CREATE TABLE [Interfaces] ( 
	[ID] int identity(1,1)  NOT NULL,
	[IDSites] int NOT NULL,
	[Origin] smallint DEFAULT 0 NOT NULL,
	[Coordinates] ntext NOT NULL,
	[Settings] ntext,
	[FieldbusSettings] smallint
)
;

CREATE TABLE [Devices] ( 
	[ID] int identity(1,1)  NOT NULL,
	[IDSites] int NOT NULL,
	[Origin] smallint DEFAULT 0 NOT NULL,
	[Coordinates] ntext NOT NULL,
	[ModelName] ntext NOT NULL,
	[IsOnline] bit NOT NULL,
	[DriverStatus] smallint,
	[IdentificationFirmwareMaskNumber] int,
	[IdentificationFirmwareRevision] int,
	[IdentificationModelNumber] int,
	[IdentificationPolycarbonateNumber] int,
	[UserDefinedLongName] ntext,
	[UserDefinedShortName] ntext,
	[UserDefinedIsPreferred] bit
)
;



--  Create Primary Key Constraints 
ALTER TABLE [Profiles] ADD CONSTRAINT [PK_Profiles] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [PermissionSettings] ADD CONSTRAINT [PK_PermissionSettings] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [Users] ADD CONSTRAINT [PK_Users] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [UserGroups] ADD CONSTRAINT [PK_UserGroups] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [Timeframes] ADD CONSTRAINT [PK_Timeframes] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [BusinessActions] ADD CONSTRAINT [PK_BusinessAction] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [AlarmCategories] ADD CONSTRAINT [PK_AlarmCategories] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [Sites] ADD CONSTRAINT [PK_ID] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [Resources] ADD CONSTRAINT [PK_ID] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [Interfaces] ADD CONSTRAINT [PK_ID] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [Devices] ADD CONSTRAINT [PK_ID] 
	PRIMARY KEY  ([ID])
;


--  Create Indexes 
CREATE INDEX [IDX_FK_Sites]
ON [Resources] ([IDSites] ASC)
;

CREATE INDEX [IDX_FK_Sites]
ON [Interfaces] ([IDSites] ASC)
;

CREATE INDEX [IDX_FK_Sites]
ON [Devices] ([IDSites] ASC)
;


--  Create Foreign Key Constraints 
ALTER TABLE [PermissionSettings] ADD CONSTRAINT [FK_UserGroups] 
	FOREIGN KEY ([IDUserGroups]) REFERENCES [UserGroups] ([ID])
;

ALTER TABLE [Users] ADD CONSTRAINT [FK_UserGroups] 
	FOREIGN KEY ([IDUserGroups]) REFERENCES [UserGroups] ([ID])
;

ALTER TABLE [AlarmCategoriesTimeframes] ADD CONSTRAINT [FK_AlarmCategoriesTimeframes_AlarmCategories] 
	FOREIGN KEY ([IDAlarmCategory]) REFERENCES [AlarmCategories] ([ID])
ON DELETE CASCADE
;

ALTER TABLE [AlarmCategoriesTimeframes] ADD CONSTRAINT [FK_AlarmCategoriesTimeframes_Timeframes] 
	FOREIGN KEY ([IDTimeframe]) REFERENCES [Timeframes] ([ID])
ON DELETE CASCADE
;

ALTER TABLE [AlarmCategoriesBusinessActions] ADD CONSTRAINT [FK_AlarmCategoriesBusinessActions_AlarmCategories] 
	FOREIGN KEY ([IDAlarmCategory]) REFERENCES [AlarmCategories] ([ID])
ON DELETE CASCADE
;

ALTER TABLE [AlarmCategoriesBusinessActions] ADD CONSTRAINT [FK_AlarmCategoriesBusinessActions_BusinessActions] 
	FOREIGN KEY ([IDBusinessAction]) REFERENCES [BusinessActions] ([ID])
ON DELETE CASCADE
;

ALTER TABLE [Resources] ADD CONSTRAINT [FK_Resources_Sites] 
	FOREIGN KEY ([IDSites]) REFERENCES [Sites] ([ID])
ON DELETE CASCADE
;

ALTER TABLE [Interfaces] ADD CONSTRAINT [FK_Interfaces_Sites] 
	FOREIGN KEY ([IDSites]) REFERENCES [Sites] ([ID])
ON DELETE CASCADE
;

ALTER TABLE [Devices] ADD CONSTRAINT [FK_Devices_Sites] 
	FOREIGN KEY ([IDSites]) REFERENCES [Sites] ([ID])
ON DELETE CASCADE
;
